@@ -16,92 +16,8 @@ from pydantic import Field, PrivateAttr
 from kiara_plugin.tabular.models import TableMetadata
 
 
-class KiaraArray(KiaraModel):
-
-    # @classmethod
-    # def create_in_temp_dir(cls, ):
-    #
-    #     temp_f = tempfile.mkdtemp()
-    #     file_path = os.path.join(temp_f, "array.feather")
-    #
-    #     def cleanup():
-    #         shutil.rmtree(file_path, ignore_errors=True)
-    #
-    #     atexit.register(cleanup)
-    #
-    #     array_obj = cls(feather_path=file_path)
-    #     return array_obj
-
-    @classmethod
-    def create_array(cls, data: Any) -> "KiaraArray":
-
-        if isinstance(data, KiaraArray):
-            return data
-
-        array_obj = None
-        if isinstance(data, (pa.Array, pa.ChunkedArray)):
-            array_obj = data
-        elif isinstance(data, pa.Table):
-            if len(data.columns) != 1:
-                raise Exception(
-                    f"Invalid type, only Arrow Arrays or single-column Tables allowed. This value is a table with {len(data.columns)} columns."
-                )
-            array_obj = data.column(0)
-        else:
-            try:
-                array_obj = pa.array(data)
-            except Exception:
-                pass
-
-        if array_obj is None:
-            raise Exception(
-                f"Can't create table, invalid source data type: {type(data)}."
-            )
-
-        obj = KiaraArray()
-        if not isinstance(array_obj, pa.lib.ChunkedArray):
-            array_obj = pa.chunked_array(array_obj)
-        obj._array_obj = array_obj
-        return obj
-
-    data_path: Optional[str] = Field(
-        description="The path to the (feather) file backing this array."
-    )
-
-    _array_obj: pa.Array = PrivateAttr(default=None)
-
-    def _retrieve_data_to_hash(self) -> Any:
-        raise NotImplementedError()
-
-    @property
-    def arrow_array(self) -> pa.Array:
-
-        if self._array_obj is not None:
-            return self._array_obj
-
-        if not self.data_path:
-            raise Exception("Can't retrieve array data, object not initialized (yet).")
-
-        with pa.memory_map(self.data_path, "r") as source:
-            table: pa.Table = pa.ipc.open_file(source).read_all()
-
-        if len(table.columns) != 1:
-            raise Exception(
-                f"Invalid serialized array data, only a single-column Table is allowed. This value is a table with {len(table.columns)} columns."
-            )
-
-        self._array_obj = table.column(0)
-        return self._array_obj
-
-    def to_pylist(self):
-        return self.arrow_array.to_pylist()
-
-    def to_pandas(self):
-        return self.arrow_array.to_pandas()
-
-
 class KiaraTable(KiaraModel):
-    """A wrapper class to manage tabular data in a hopefully memory efficient way."""
+    """A wrapper class to manage tabular data in a memory efficient way."""
 
     @classmethod
     def create_table(cls, data: Any) -> "KiaraTable":
@@ -254,7 +170,11 @@ class RenderTableInstruction(RenderInstruction):
 
         assert columnns
 
-        query = f"""SELECT {', '.join(columnns)} FROM data ORDER by {', '.join(columnns)} LIMIT {self.number_of_rows} OFFSET {self.row_offset}"""
+        columnns = [f'"{x}"' if not x.startswith('"') else x for x in columnns]
+
+        # query = f"""SELECT {', '.join(columnns)} FROM data ORDER by {', '.join(columnns)} LIMIT {self.number_of_rows} OFFSET {self.row_offset}"""
+
+        query = f"""SELECT {', '.join(columnns)} FROM data LIMIT {self.number_of_rows} OFFSET {self.row_offset}"""
 
         rel_from_arrow = duckdb.arrow(table.arrow_table)
         query_result: duckdb.DuckDBPyResult = rel_from_arrow.query("data", query)
@@ -262,31 +182,35 @@ class RenderTableInstruction(RenderInstruction):
         result_table = query_result.fetch_arrow_table()
 
         wrap = ArrowTabularWrap(table=result_table)
-        pretty = wrap.pretty_print()
+        pretty = wrap.pretty_print(max_row_height=1)
 
         related_instructions = {}
 
-        related_instructions["first"] = RenderTableInstruction.construct(
-            **{"row_offset": 0, "columns": self.columns}
-        )
-
-        if self.row_offset > 0:
-            p_offset = self.row_offset - self.number_of_rows
-            if p_offset < 0:
-                p_offset = 0
-            previous = {"row_offset": p_offset, "columns": self.columns}
-            related_instructions["previous"] = RenderTableInstruction.construct(
-                **previous
+        row_offset = table.num_rows - self.number_of_rows
+        if row_offset > 0:
+            related_instructions["first"] = RenderTableInstruction.construct(
+                **{"row_offset": 0, "columns": self.columns}
             )
 
-        n_offset = self.row_offset + self.number_of_rows
-        if n_offset < table.num_rows:
-            next = {"row_offset": n_offset, "columns": self.columns}
-            related_instructions["next"] = RenderTableInstruction.construct(**next)
+            if self.row_offset > 0:
+                p_offset = self.row_offset - self.number_of_rows
+                if p_offset < 0:
+                    p_offset = 0
+                previous = {"row_offset": p_offset, "columns": self.columns}
+                related_instructions["previous"] = RenderTableInstruction.construct(
+                    **previous
+                )
 
-        related_instructions["last"] = RenderTableInstruction.construct(
-            **{"row_offset": table.num_rows - self.number_of_rows, "columns": columnns}
-        )
+            n_offset = self.row_offset + self.number_of_rows
+            if n_offset < table.num_rows:
+                next = {"row_offset": n_offset, "columns": self.columns}
+                related_instructions["next"] = RenderTableInstruction.construct(**next)
+
+            if row_offset < 0:
+                row_offset = 0
+            related_instructions["last"] = RenderTableInstruction.construct(
+                **{"row_offset": row_offset, "columns": columnns}
+            )
 
         render_metadata = RenderMetadata(related_instructions=related_instructions)
 
